@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
 version: 2.1.6
-id: persistent-template-2.1.6-4e0b8e5fb625cf28c56640a274b922ab
-key: persi_K376nDLkqZuIE92ONSttdQ
+id: persistent-template-2.1.6-1493d56e17183452cb446159287a778d
+key: persi_5nTggnWEZsaHRwSI4xx5EA
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -20,10 +20,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.6
-hs-libraries: HSpersistent-template-2.1.6-K376nDLkqZuIE92ONSttdQ
+hs-libraries: HSpersistent-template-2.1.6-5nTggnWEZsaHRwSI4xx5EA
 depends:
-    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
-    aeson-compat-0.3.1.0-bfa611031401a0b70e24a4b661ddccc6
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-compat-0.3.2.0-725b78f3168d9bafe282f8360603746a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
@@ -32,7 +32,7 @@ depends:
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
-    persistent-2.2.4.1-263fc3840b78e27a8a6fefdb05730e03
+    persistent-2.2.4.1-e7a8900dd9bde9ebb31b88aa3930cc01
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
